import { useEffect, useState } from "react";
import { getData, IItem } from "./data/getData";
import DataGrid from "./DataGrid";
import { generateGridExportFile } from "./store/grid/GridSlice";
import { useAppDispatch } from "./store/store";

function App() {
  const [data, setData] = useState<IItem[]>([]);
  const dispatch = useAppDispatch();

  useEffect(() => {
    const dataLoader = async () => {
      setData(await getData());
    };

    dataLoader();
  }, []);

  return (
    <>
      <div
        style={{
          marginBottom: "1em"
        }}
      >
        <button
          onClick={() => {
            dispatch(generateGridExportFile({
              gridId: "wijmo-export-example-grid",
            }));
          }}
        >
          Export Grid
        </button>
      </div>

      <DataGrid
        id="wijmo-export-example-grid"
        height={400}
        dataSource="array"
        gridColumns={[
          {
            uid: "id",
            field: "id",
            headerText: "Id",
            type: "number",
            width: 125,
          },
          {
            uid: "title",
            field: "title",
            headerText: "Title",
            type: "string",
            width: 125,
            template: (row: IItem) => (
              <>
                {row.title}{row.hasOpenIssues ? "*" : ""}
              </>
            ),
          },
          {
            uid: "assignedTo",
            field: "assignedTo",
            headerText: "Assigned To",
            type: "string",
            width: 200,
            template: (row: IItem) => (
              <>
                {row.assignedTo} (User)
              </>
            )
          },
          {
            uid: "issues",
            headerText: "Issues",
            type: "string",
            width: 125,
            template: (row: IItem) => (
              <span
                style={row.openIssues > 0
                  ? {
                    backgroundColor: "pink"
                  } : undefined
                }
              >
                {row.openIssues} / {row.closedIssues} ({row.openIssues + row.closedIssues})
              </span>
            ),
          },
          {
            uid: "hasOpenIssues",
            field: "hasOpenIssues",
            headerText: "Has Open Issues",
            type: "boolean",
            width: 200,
          },
        ]}
        allowColumnReordering={true}
        allowExcelExport={true}
        allowPaging={true}
        allowResizing={true}
        dataArray={data}
      />
    </>
  );
}

export default App;
